import { Plugin } from 'prosemirror-state';

export const plusButtonPlugin = new Plugin({
  view(editorView) {
    const button = document.createElement('button');
    button.textContent = '+';
    button.className = 'plus-button'

    button.style.position = 'absolute';
    button.style.zIndex = '10';
    button.style.display = 'none'; // Hide initially

    editorView.dom.appendChild(button);

    button.addEventListener('click', () => {
      console.log('Plus button clicked');
      // Add logic to open dropdown or execute commands
    });

    return {
        update(view) {
          const { $from } = view.state.selection;

          // Only show the button when the cursor is in a text block with no content
          if ($from.parent.isTextblock && $from.parent.content.size === 0) {
            const coords = view.coordsAtPos($from.pos);
            // Position the button relative to the cursor
            button.style.top = `${coords.top + window.scrollY}px`; // Added scroll offset for better positioning
            button.style.left = `${coords.left + window.scrollX - 30}px`; // Added scroll offset
            button.style.display = 'block'; // Make the button visible
          } else {
            button.style.display = 'none'; // Hide the button when not in valid position
          }
        },
        destroy() {
          button.remove(); // Cleanup on destroy
        },
    };
  },
});
